==> PhaseTypeR_1.0.0.tar.gz: PhaseTypeR/tests/testthat/_snaps/MPH_functions.md <==
# test all outputs of the phase-type functions

    WAoAAAACAAQAAgACAwAAAAIOAAAAVD/v////////AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA
    P9eLVjYs7zc/2hXkVbsYdj/Gsk5+PookP9IRVhAcCA4/wVKqo7+Byz/HyP15JYcAP7+l0oWl
    bqc/yhXkVbsYdj+pfbDMzrCuP7a7VQCd0Aw/tkH8RoS3xz/BdUzlVZ6uP5LBVbghPPM/peNR
    GfwO/z+w0QRVtNOmP7fI/XklhwA/e5k/4A1TdT+VFfGxpgtKP6sMjsQxUIo/sGeiMbB1PD9k
    TlHxE9TVP4RQMe5PYFY/psNeXuIC8T+mu1UAndAMP03ha5wkqY4/c5Gw27Ue+j+jvMYSTrh6
    P5+KRCWOF3A/NfwhBBAnrD9i2ipWDMBIP6Fu82I6eYc/leNRGfwO/z8gLPIlJlRZP1IpXPiT
    p4o/nyNL7WPhRj+OYagCja8aPwfNebVkfJo/QX8Jtv9vKj+b/Iy51rUhP4UV8bGmC0o+8YNU
    I49nYz8w2vPTFlC6P5k/K0R/W5s/fUS17+Ywqj7ZxUw7Q7yKPyA84Mg5ZUI/ltKqD1kk4j90
    UDHuT2BWPsL2BTuYHZc/D0kwbS0C1T+Up/+LKI6XP2wyOQly4U8+q+bG/bAWET7+I8eeG7Dx
    P5K1MmnRZMk/Y5Gw27Ue+j6Uh1yiJ+w3Pu0JHn+nYLQ/kPMWM7XrWD9bKcozPrYtPn41W7ru
    hco+2/jQQ49zWD+OuDyU+SD9P1LaKlYMwEg+ZjnjF1ponD7K8nvM9tELP4vXfyGLoxg/SisL
    RmHEpD5QWmKMaZ+gPrn1w43Buxc/iTw2ranRsj9CKVz4k6eKPjgQVv8sV3E+qQJNZThvJT+G
    36ArLbgQPzk1oXAS1es+IbSGVfNyZj6YF8J/4rSTP4S7u6YzhwI/MX8Jtv9vKgAABAIAAAAB
    AAQACQAAAANkaW0AAAANAAAAAgAAAAQAAAAVAAAA/g==

---

    WAoAAAACAAQAAgACAwAAAAIOAAAAQDygAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA
    P+Q6VOTpiGQ/3dsqcUBFMD/DH4kPsKJoP8xDP/96pWA/66tVVxAfjT/n6e000SKNP9Ms9WA1
    c84/3dsqcUBFMD/uaCTzMxT1P+wcmkwgOYI/2c7EY02tjD/kS3Ox2yIXP+9p9VI+9hg/7iCU
    ZPC/2j/eocfZ1KbkP+fp7TTRIo0/78jNgD/lWT/vGRJx8ku0P+EyQx3rIuc/6mVGjoFp1j/v
    67GuDuwrP++QxBSQxj4/4r6NXCeDKT/sHJpMIDmCP+/4h6UY9tY/78prooHEwj/kEVHX/gfn
    P+1NNybL1dM/7/1Ae999+z/v5jEPivk3P+U59IPK67I/7iCUZPC/2j/v/v0w3a2bP+/zkYzL
    sGg/5kGCs2Ju5j/us0RVCjd6P+//oMoZKm4/7/oDEW3VwD/nLbCfN2LkP+8ZEnHyS7Q/7//c
    +Ve44T/v/R2c4l3VP+gCYvPuwSQ/71+6apFdsj/v//MdWeJeP+/+nFTcZgM/6MJ6Mj8Wtz/v
    kMQUkMY+P+//+0J+sRo/7/9Urjf0uT/pcDy4477hP++yzL+S5ew/7//+QZOQJT/v/616dFLh
    P+oNjucBdCw/78prooHEwj/v//9bxRrvP+//2EAvUUo/6pwRk7t8jj/v2tBg6d8hAAAEAgAA
    AAEABAAJAAAAA2RpbQAAAA0AAAACAAAABAAAABAAAAD+

---

    WAoAAAACAAQAAgACAwAAAAIOAAAAUD+6+OAYDT1DP9JMD3A8Yz0/51BNeStCbT/iS5UxuI1C
    P8OdkAYb9pA/1ycqR9r6uT/usMjbcctQP+cnOb4nXwY/yg9VIa+yND/b4ZrfYAJmP/M7c4P6
    19A/6+GnSanCcj/QbAJWPcWdP+BQNdEDVa8/93UEWyK9jz/wUCIwNHwwP9QAih4FBd0/4r29
    jM8yeD/8JZuRtgUbP/K9t/craKs/18whhtSt5T/lQy50ws7yQAC3zXATQp8/9UNM5Gqx9j/b
    1G1iVXVYP+fpphZ3NudAA71bwcQznD/36aJlMuVMP+ARIw2t4HQ/6rmk0fQR9UAHOqXyK7Y4
    P/q5j1fA5Ts/4l+zRxGWez/tvHmkSFKRQAtKRialV70//byYFv7Zfj/k3GYy0QPSP/B+vxpz
    059AEAUJtviMeUAAfqpu7C/hP+eOtWCFntk/8kQLJtNLkUASzK+66NIqQAJEKybTS5M/6oB/
    VUL8Uz/0NilAiMklQBYLi9HI1NhABDZJQIjJKD/tvpCr0mtMP/ZesrD17LxAGdDDVoEdpUAG
    Xpwv9tXyP/CtY7IAAyY/+MlqlVqQhUAeLRCz+DhjQAjJapVakIU/8rYztnYMrT/7h0LroFUf
    QCGbq4U2C2tAC4dTq+SkBj/1CyIC7XWWP/6wBpipd3xAJInEYtdgJUAOr+aYqXd4P/fF8a8w
    XitAATNlsiRP0kAn/rjzSTMHQBEzZbIkT9I/+xEsrJe+U0ADcqRgZKe1QCwt/phZ+TZAE3Kk
    YGSntT//OBASoou4QAZJP9RE9yZAMLsjx5zHQ0AWST/URPcmQAJruPmuRFZACiIJJqM/1UA0
    TwmX1nAGQBoiCSajP9UAAAQCAAAAAQAEAAkAAAADZGltAAAADQAAAAIAAAAEAAAAFAAAAP4=

==> PhaseTypeR_1.0.1.tar.gz: PhaseTypeR/tests/testthat/_snaps/MPH_functions.md <==
# test all outputs of the phase-type functions

    WAoAAAACAAQBAQACAwAAAAIOAAAAVD/v////////AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA
    P9eLVjYs7zc/2hXkVbsYdj/Gsk5+PookP9IRVhAcCA4/wVKqo7+Byz/HyP15JYcAP7+l0oWl
    bqc/yhXkVbsYdj+pfbDMzrCuP7a7VQCd0Aw/tkH8RoS3xz/BdUzlVZ6uP5LBVbghPPM/peNR
    GfwO/z+w0QRVtNOmP7fI/XklhwA/e5k/4A1TdT+VFfGxpgtKP6sMjsQxUIo/sGeiMbB1PD9k
    TlHxE9TVP4RQMe5PYFY/psNeXuIC8T+mu1UAndAMP03ha5wkqY4/c5Gw27Ue+j+jvMYSTrh6
    P5+KRCWOF3A/NfwhBBAnrD9i2ipWDMBIP6Fu82I6eYc/leNRGfwO/z8gLPIlJlRZP1IpXPiT
    p4o/nyNL7WPhRj+OYagCja8aPwfNebVkfJo/QX8Jtv9vKj+b/Iy51rUhP4UV8bGmC0o+8YNU
    I49nYz8w2vPTFlC6P5k/K0R/W5s/fUS17+Ywqj7ZxUw7Q7yKPyA84Mg5ZUI/ltKqD1kk4j90
    UDHuT2BWPsL2BTuYHZc/D0kwbS0C1T+Up/+LKI6XP2wyOQly4U8+q+bG/bAWET7+I8eeG7Dx
    P5K1MmnRZMk/Y5Gw27Ue+j6Uh1yiJ+w3Pu0JHn+nYLQ/kPMWM7XrWD9bKcozPrYtPn41W7ru
    hco+2/jQQ49zWD+OuDyU+SD9P1LaKlYMwEg+ZjnjF1ponD7K8nvM9tELP4vXfyGLoxg/SisL
    RmHEpD5QWmKMaZ+gPrn1w43Buxc/iTw2ranRsj9CKVz4k6eKPjgQVv8sV3E+qQJNZThvJT+G
    36ArLbgQPzk1oXAS1es+IbSGVfNyZj6YF8J/4rSTP4S7u6YzhwI/MX8Jtv9vKgAABAIAAAAB
    AAQACQAAAANkaW0AAAANAAAAAgAAAAQAAAAVAAAA/g==

---

    WAoAAAACAAQBAQACAwAAAAIOAAAAQDygAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA
    P+Q6VOTpiGQ/3dsqcUBFMD/DH4kPsKJoP8xDP/96pWA/66tVVxAfjT/n6e000SKNP9Ms9WA1
    c84/3dsqcUBFMD/uaCTzMxT1P+wcmkwgOYI/2c7EY02tjD/kS3Ox2yIXP+9p9VI+9hg/7iCU
    ZPC/2j/eocfZ1KbkP+fp7TTRIo0/78jNgD/lWT/vGRJx8ku0P+EyQx3rIuc/6mVGjoFp1j/v
    67GuDuwrP++QxBSQxj4/4r6NXCeDKT/sHJpMIDmCP+/4h6UY9tY/78prooHEwj/kEVHX/gfn
    P+1NNybL1dM/7/1Ae999+z/v5jEPivk3P+U59IPK67I/7iCUZPC/2j/v/v0w3a2bP+/zkYzL
    sGg/5kGCs2Ju5j/us0RVCjd6P+//oMoZKm4/7/oDEW3VwD/nLbCfN2LkP+8ZEnHyS7Q/7//c
    +Ve44T/v/R2c4l3VP+gCYvPuwSQ/71+6apFdsj/v//MdWeJeP+/+nFTcZgM/6MJ6Mj8Wtz/v
    kMQUkMY+P+//+0J+sRo/7/9Urjf0uT/pcDy4477hP++yzL+S5ew/7//+QZOQJT/v/616dFLh
    P+oNjucBdCw/78prooHEwj/v//9bxRrvP+//2EAvUUo/6pwRk7t8jj/v2tBg6d8hAAAEAgAA
    AAEABAAJAAAAA2RpbQAAAA0AAAACAAAABAAAABAAAAD+

---

    WAoAAAACAAQBAQACAwAAAAIOAAAAUD+6+OAYDT1DP9JMD3A8Yz0/51BNeStCbT/iS5UxuI1C
    P8OdkAYb9pA/1ycqR9r6uT/usMjbcctQP+cnOb4nXwY/yg9VIa+yND/b4ZrfYAJmP/M7c4P6
    19A/6+GnSanCcj/QbAJWPcWdP+BQNdEDVa8/93UEWyK9jz/wUCIwNHwwP9QAih4FBd0/4r29
    jM8yeD/8JZuRtgUbP/K9t/craKs/18whhtSt5T/lQy50ws7yQAC3zXATQp8/9UNM5Gqx9j/b
    1G1iVXVYP+fpphZ3NudAA71bwcQznD/36aJlMuVMP+ARIw2t4HQ/6rmk0fQR9UAHOqXyK7Y4
    P/q5j1fA5Ts/4l+zRxGWez/tvHmkSFKRQAtKRialV70//byYFv7Zfj/k3GYy0QPSP/B+vxpz
    059AEAUJtviMeUAAfqpu7C/hP+eOtWCFntk/8kQLJtNLkUASzK+66NIqQAJEKybTS5M/6oB/
    VUL8Uz/0NilAiMklQBYLi9HI1NhABDZJQIjJKD/tvpCr0mtMP/ZesrD17LxAGdDDVoEdpUAG
    Xpwv9tXyP/CtY7IAAyY/+MlqlVqQhUAeLRCz+DhjQAjJapVakIU/8rYztnYMrT/7h0LroFUf
    QCGbq4U2C2tAC4dTq+SkBj/1CyIC7XWWP/6wBpipd3xAJInEYtdgJUAOr+aYqXd4P/fF8a8w
    XitAATNlsiRP0kAn/rjzSTMHQBEzZbIkT9I/+xEsrJe+U0ADcqRgZKe1QCwt/phZ+TZAE3Kk
    YGSntT//OBASoou4QAZJP9RE9yZAMLsjx5zHQ0AWST/URPcmQAJruPmuRFZACiIJJqM/1UA0
    TwmX1nAGQBoiCSajP9UAAAQCAAAAAQAEAAkAAAADZGltAAAADQAAAAIAAAAEAAAAFAAAAP4=
